==> eiffelstudio-18.07.10.1981.tar: F_code/C4/xm153.c <==
/*
 * Code for class XM_CALLBACKS_TO_TREE_FILTER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm153.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_CALLBACKS_TO_TREE_FILTER}.initialize */
void F216_1884 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTLNSMART(eif_new_type(1209, 0).id);
	F1210_8583(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) NULL;
	{
		static EIF_TYPE_INDEX typarr0[] = {1149,946,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F1146_7782(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.document */
EIF_REFERENCE F216_1885 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {XM_CALLBACKS_TO_TREE_FILTER}.last_position_table */
EIF_REFERENCE F216_1887 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {XM_CALLBACKS_TO_TREE_FILTER}.enable_position_table */
void F216_1888 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) arg1;
	tr1 = RTLNSMART(eif_new_type(22, 0).id);
	F23_284(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_start */
void F216_1890 (EIF_REFERENCE Current)
{
	GTCX
	
	
	F216_1884(Current);
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_start_tag */
void F216_1891 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	RTLD;
	
	RTLI(10);
	RTLR(0,loc2);
	RTLR(1,arg1);
	RTLR(2,loc3);
	RTLR(3,Current);
	RTLR(4,tr1);
	RTLR(5,loc1);
	RTLR(6,arg3);
	RTLR(7,arg2);
	RTLR(8,tr2);
	RTLR(9,tr3);
	RTLIU(10);
	
	RTGC;
	RTCT0("has_resolved_namespaces", EX_CHECK);
	loc2 = arg1;
	if (EIF_TEST(loc2)) {
		RTCK0;
	} else {
		RTCF0;
	}
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc3 = tr1;
	if (EIF_TEST(loc3)) {
		tr1 = RTLNS(eif_new_type(1210, 0x00).id, 1210, _OBJSIZ_4_0_0_0_0_0_0_0_);
		tr2 = F216_1898(Current, loc2, arg2);
		F1211_8599(RTCW(tr1), loc3, arg3, tr2);
		loc1 = (EIF_REFERENCE) tr1;
	} else {
		tr1 = RTLNS(eif_new_type(1210, 0x00).id, 1210, _OBJSIZ_4_0_0_0_0_0_0_0_);
		tr2 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr3 = F216_1898(Current, loc2, arg2);
		F1211_8600(RTCW(tr1), tr2, arg3, tr3);
		loc1 = (EIF_REFERENCE) tr1;
	}
	RTAR(Current, loc1);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) loc1;
	F216_1900(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_attribute */
void F216_1892 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(10);
	RTLR(0,loc2);
	RTLR(1,arg1);
	RTLR(2,loc3);
	RTLR(3,Current);
	RTLR(4,tr1);
	RTLR(5,loc1);
	RTLR(6,arg3);
	RTLR(7,arg2);
	RTLR(8,tr2);
	RTLR(9,arg4);
	RTLIU(10);
	
	RTGC;
	RTCT0("has_resolved_namespaces", EX_CHECK);
	loc2 = arg1;
	if (EIF_TEST(loc2)) {
		RTCK0;
	} else {
		RTCF0;
	}
	RTCT0("element_not_void", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc3 = tr1;
	if (EIF_TEST(loc3)) {
		RTCK0;
	} else {
		RTCF0;
	}
	tr1 = RTLNS(eif_new_type(1207, 0x00).id, 1207, _OBJSIZ_4_0_0_0_0_0_0_0_);
	tr2 = F216_1898(Current, loc2, arg2);
	F1208_8536(RTCW(tr1), arg3, tr2, arg4, loc3);
	loc1 = (EIF_REFERENCE) tr1;
	F216_1900(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_content */
void F216_1893 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTGC;
	RTCT0("not_finished", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		RTCK0;
	} else {
		RTCF0;
	}
	tr1 = RTLNS(eif_new_type(1205, 0x00).id, 1205, _OBJSIZ_2_0_0_0_0_0_0_0_);
	F1206_8519(RTCW(tr1), loc2, arg1);
	loc1 = (EIF_REFERENCE) tr1;
	F216_1900(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_end_tag */
void F216_1894 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc2);
	RTLIU(4);
	
	RTGC;
	RTCT0("open_composite_exists", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTCK0;
	} else {
		RTCF0;
	}
	tb1 = '\01';
	tr1 = *(EIF_REFERENCE *)(loc1);
	loc2 = tr1;
	if (!((EIF_BOOLEAN) !EIF_TEST(loc2))) {
		tb2 = F1200_8494(loc2);
		tb1 = tb2;
	}
	if (tb1) {
		*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) NULL;
	} else {
		tr1 = F1200_8491(loc1);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
	}
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_processing_instruction */
void F216_1895 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(7);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,arg1);
	RTLR(5,arg2);
	RTLR(6,tr2);
	RTLIU(7);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		tr1 = RTLNS(eif_new_type(1204, 0x00).id, 1204, _OBJSIZ_3_0_0_0_0_0_0_0_);
		F1205_8511(RTCW(tr1), loc2, arg1, arg2);
		loc1 = (EIF_REFERENCE) tr1;
	} else {
		tr1 = RTLNS(eif_new_type(1204, 0x00).id, 1204, _OBJSIZ_3_0_0_0_0_0_0_0_);
		tr2 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		F1205_8512(RTCW(tr1), tr2, arg1, arg2);
		loc1 = (EIF_REFERENCE) tr1;
	}
	F216_1900(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_comment */
void F216_1896 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(6);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,arg1);
	RTLR(5,tr2);
	RTLIU(6);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		tr1 = RTLNS(eif_new_type(1203, 0x00).id, 1203, _OBJSIZ_2_0_0_0_0_0_0_0_);
		F1204_8505(RTCW(tr1), loc2, arg1);
		loc1 = (EIF_REFERENCE) tr1;
	} else {
		tr1 = RTLNS(eif_new_type(1203, 0x00).id, 1203, _OBJSIZ_2_0_0_0_0_0_0_0_);
		tr2 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		F1204_8506(RTCW(tr1), tr2, arg1);
		loc1 = (EIF_REFERENCE) tr1;
	}
	F216_1900(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.current_element */
EIF_REFERENCE F216_1897 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


/* {XM_CALLBACKS_TO_TREE_FILTER}.new_namespace */
EIF_REFERENCE F216_1898 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,tr1);
	RTLR(1,arg2);
	RTLR(2,arg1);
	RTLR(3,Result);
	RTLR(4,Current);
	RTLIU(5);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(946, 0x00).id, 946, _OBJSIZ_2_0_0_0_0_0_0_0_);
	F947_6201(RTCW(tr1), arg2, arg1);
	Result = (EIF_REFERENCE) tr1;
	tb1 = '\0';
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	tb2 = F1146_7787(RTCW(tr1), Result);
	if (tb2) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		tr1 = F1146_7785(RTCW(tr1), Result);
		tb2 = F947_6208(RTCW(tr1), Result);
		tb1 = tb2;
	}
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		Result = F1146_7785(RTCW(tr1), Result);
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		F1146_7798(RTCW(tr1), Result);
	}
	RTLE;
	return Result;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.namespace_cache */
EIF_REFERENCE F216_1899 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_4_);
}


/* {XM_CALLBACKS_TO_TREE_FILTER}.handle_position */
void F216_1900 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc2);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	loc1 = tr1;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_5_);
	loc2 = tr1;
	if ((EIF_BOOLEAN) (EIF_TEST(loc1) && EIF_TEST(loc2))) {
		tr1 = F1235_9299(loc2);
		F23_287(loc1, tr1, arg1);
	}
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.source_parser */
EIF_REFERENCE F216_1901 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_5_);
}


void EIF_Minit153 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C4/xm153.c <==
/*
 * Code for class XM_CALLBACKS_TO_TREE_FILTER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm153.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_CALLBACKS_TO_TREE_FILTER}.initialize */
void F216_1905 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTLNSMART(eif_new_type(1217, 1).id);
	F1218_8658(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) NULL;
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,1155,0xFF01,947,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F1152_7850(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.enable_position_table */
void F216_1909 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) arg1;
	tr1 = RTLNSMART(eif_new_type(22, 0).id);
	F23_302(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_start */
void F216_1911 (EIF_REFERENCE Current)
{
	GTCX
	
	
	F216_1905(Current);
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_start_tag */
void F216_1912 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(9);
	RTLR(0,loc2);
	RTLR(1,arg1);
	RTLR(2,loc3);
	RTLR(3,Current);
	RTLR(4,tr1);
	RTLR(5,loc1);
	RTLR(6,arg3);
	RTLR(7,arg2);
	RTLR(8,tr2);
	RTLIU(9);
	
	RTGC;
	RTCT0("has_resolved_namespaces", EX_CHECK);
	loc2 = arg1;
	if (EIF_TEST(loc2)) {
		RTCK0;
	} else {
		RTCF0;
	}
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc3 = tr1;
	if (EIF_TEST(loc3)) {
		loc1 = RTLNS(eif_new_type(1218, 0x01).id, 1218, _OBJSIZ_4_0_0_0_0_0_0_0_);
		tr1 = F216_1919(Current, loc2, arg2);
		F1219_8674(RTCW(loc1), loc3, arg3, tr1);
	} else {
		loc1 = RTLNS(eif_new_type(1218, 0x01).id, 1218, _OBJSIZ_4_0_0_0_0_0_0_0_);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr2 = F216_1919(Current, loc2, arg2);
		F1219_8675(RTCW(loc1), tr1, arg3, tr2);
	}
	RTAR(Current, loc1);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) loc1;
	F216_1921(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_attribute */
void F216_1913 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(9);
	RTLR(0,loc2);
	RTLR(1,arg1);
	RTLR(2,loc3);
	RTLR(3,Current);
	RTLR(4,tr1);
	RTLR(5,loc1);
	RTLR(6,arg3);
	RTLR(7,arg2);
	RTLR(8,arg4);
	RTLIU(9);
	
	RTGC;
	RTCT0("has_resolved_namespaces", EX_CHECK);
	loc2 = arg1;
	if (EIF_TEST(loc2)) {
		RTCK0;
	} else {
		RTCF0;
	}
	RTCT0("element_not_void", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc3 = tr1;
	if (EIF_TEST(loc3)) {
		RTCK0;
	} else {
		RTCF0;
	}
	loc1 = RTLNS(eif_new_type(1215, 0x01).id, 1215, _OBJSIZ_4_0_0_0_0_0_0_0_);
	tr1 = F216_1919(Current, loc2, arg2);
	F1216_8611(RTCW(loc1), arg3, tr1, arg4, loc3);
	F216_1921(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_content */
void F216_1914 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTGC;
	RTCT0("not_finished", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		RTCK0;
	} else {
		RTCF0;
	}
	loc1 = RTLNS(eif_new_type(1213, 0x01).id, 1213, _OBJSIZ_2_0_0_0_0_0_0_0_);
	F1214_8594(RTCW(loc1), loc2, arg1);
	F216_1921(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_end_tag */
void F216_1915 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc2);
	RTLIU(4);
	
	RTGC;
	RTCT0("open_composite_exists", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTCK0;
	} else {
		RTCF0;
	}
	tb1 = '\01';
	tr1 = *(EIF_REFERENCE *)(loc1);
	loc2 = tr1;
	if (!((EIF_BOOLEAN) !(EIF_TRUE))) {
		tb2 = F1208_8569(loc2);
		tb1 = tb2;
	}
	if (tb1) {
		*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) NULL;
	} else {
		tr1 = F1208_8566(loc1);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
	}
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_processing_instruction */
void F216_1916 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(6);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,arg1);
	RTLR(5,arg2);
	RTLIU(6);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		loc1 = RTLNS(eif_new_type(1211, 0x01).id, 1211, _OBJSIZ_3_0_0_0_0_0_0_0_);
		F1212_8580(RTCW(loc1), loc2, arg1, arg2);
	} else {
		loc1 = RTLNS(eif_new_type(1211, 0x01).id, 1211, _OBJSIZ_3_0_0_0_0_0_0_0_);
		F1212_8581(RTCW(loc1), *(EIF_REFERENCE *)(Current + _REFACS_1_), arg1, arg2);
	}
	F216_1921(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_comment */
void F216_1917 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		loc1 = RTLNS(eif_new_type(1212, 0x01).id, 1212, _OBJSIZ_2_0_0_0_0_0_0_0_);
		F1213_8588(RTCW(loc1), loc2, arg1);
	} else {
		loc1 = RTLNS(eif_new_type(1212, 0x01).id, 1212, _OBJSIZ_2_0_0_0_0_0_0_0_);
		F1213_8589(RTCW(loc1), *(EIF_REFERENCE *)(Current + _REFACS_1_), arg1);
	}
	F216_1921(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.new_namespace */
EIF_REFERENCE F216_1919 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,arg2);
	RTLR(1,arg1);
	RTLR(2,Result);
	RTLR(3,Current);
	RTLR(4,tr1);
	RTLIU(5);
	
	RTGC;
	Result = RTLNS(eif_new_type(947, 0x01).id, 947, _OBJSIZ_2_0_0_0_0_0_0_0_);
	F948_6245(RTCW(Result), arg2, arg1);
	tb1 = '\0';
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	tb2 = F1152_7855(RTCW(tr1), Result);
	if (tb2) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		tr1 = F1152_7853(RTCW(tr1), Result);
		tb2 = F948_6252(RTCW(tr1), Result);
		tb1 = tb2;
	}
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		tr1 = F1152_7853(RTCW(tr1), Result);
		Result = (EIF_REFERENCE) tr1;
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		F1152_7866(RTCW(tr1), Result);
	}
	RTLE;
	return Result;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.handle_position */
void F216_1921 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc2);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	loc1 = tr1;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_5_);
	loc2 = tr1;
	if ((EIF_BOOLEAN) (EIF_TEST(loc1) && EIF_TEST(loc2))) {
		tr1 = F1243_9374(loc2);
		F23_305(loc1, tr1, arg1);
	}
	RTLE;
}

void EIF_Minit153 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
